==> haskell-memotrie-0.6.9-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-GXLwsuhOJCZCdZCZX6oUKB
key: MemoTrie-0.6.9-GXLwsuhOJCZCdZCZX6oUKB
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: b2b29d390887d369bf1c099dd52e79e6
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-GXLwsuhOJCZCdZCZX6oUKB
depends:
    base-4.11.1.0 newtype-generics-0.5.3-BWm5yLCJATCJvgmpsXBla6
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             newtype-generics-0.5.3-BWm5yLCJATCJvgmpsXBla6=1e72daf8ddde63350948b24395410157
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.9-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-678sI9SAq3g1fHOk5vVutn
key: MemoTrie-0.6.9-678sI9SAq3g1fHOk5vVutn
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: f77142e9d330c3196e0f63410820739c
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.6.1/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-678sI9SAq3g1fHOk5vVutn
depends:
    base-4.12.0.0 newtype-generics-0.5.3-3opHQooccrjK6s9pqYYgod
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
